#!/bin/bash
#
# Copyright (c) 2007, by Broadcom, Inc.
# All Rights Reserved.
#

function distmgr_currdist()
{
	local -a distver
	local    platform

	if [ -f /etc/redhat-release ]; then

		# Extract the major and minor version numbers from the
		# redhat-release file.
		distver=(`sed -e 's/.*release \([0-9]\).* \([0-9]\)*.*/\1 \2/' /etc/redhat-release`)

		if [ ${distver[0]} -gt 4 -a ${distver[0]} -lt 7 ]; then
			distver[1]=`sed -e 's/.*release [0-9].\([0-9]*\).*/\1/' /etc/redhat-release`
		fi

		if [ -z "${distver[1]}" ]; then
			platform=rhel${distver[0]}
		else
			platform=rhel${distver[0]}sp${distver[1]}
		fi

	elif [ -f /etc/SuSE-release ]; then

		# Extract the major and minor version numbers from the
		# SuSE-release file.
		distver=(`egrep 'VERSION|PATCHLEVEL' /etc/SuSE-release | sed -e 's/.*= //'`)

		if [ -z "${distver[1]}" ]; then
			platform=sles${distver[0]}
		else
			platform=sles${distver[0]}sp${distver[1]}
		fi

	else

		platform="UNSUPPORTED"

	fi

	# TODO -- 32bit, 64bit?

	echo $platform
}


function distmgr_mkbarekernlist()
{
	local krnlst
	local platform

	platform=$1

	while IFS=' ': read -ra line; do

		# Skip comment lines.
		if [ "${line[0]:0:1}" = "#" ]; then
			continue
		fi

		# Skip lines that do not match our distro.
		if [ "${line[0]}" != "$platform" ]; then
			continue
		fi

		# Skip lines that do not match our hardware platform.
		if [ "${line[1]}" != "`uname -i`" ]; then
			continue
		fi

		krnlst="${line[3]}"
		break

	done

	echo $krnlst
}

function distmgr_mkinstkernlist()
{
        local krnlst
        local platform

        platform=$1

        while IFS=' ': read -ra line; do

                # Skip comment lines.
                if [ "${line[0]:0:1}" = "#" ]; then
                        continue
                fi

                # Skip lines that do not match our distro.
                if [ "${line[0]}" != "$platform" ]; then
                        continue
                fi

                # Skip lines that do not match our hardware platform.
                if [ "${line[1]}" != "`uname -i`" ]; then
                        continue
                fi

                # The variants portion of our configuration file is a
                # comma-delimited list of kernel variants for the platform.
                # Replace the commas with spaces so that we can process
                # them individually.
                for variant in ${line[4]//,/ }; do

                        krnlst="$krnlst $variant"

                done

        done

        echo $krnlst
}

[ $# == 0 ] && exit;
[ $1 == "kvers" ] && distmgr_mkbarekernlist `distmgr_currdist` && exit
[ $1 == "kflav" ] && distmgr_mkinstkernlist `distmgr_currdist` && exit
[ $1 == "ldist" ] && distmgr_currdist && exit
